@@ -1,3 +1,4 @@
+import os
 import re
 
 from pydriller.domain.commit import ModificationType
@@ -15,6 +16,8 @@ BUG_RELATED_LABELS = {'bug', 'Bug', 'bug :bug:', 'Bug - Medium', 'Bug - Low', 'B
 
 FIXING_COMMITS_REGEX = r'(bug|fix|error|crash|problem|fail|defect|patch)'
 
+full_name_pattern = re.compile(r'git(hub|lab){1}\.com/([\w\W]+)\.git')
+
 
 class BaseMiner:
     """
@@ -22,27 +25,16 @@ class BaseMiner:
     """
 
     def __init__(self,
-                 access_token: str,
-                 path_to_repo: str,
-                 host: str,
-                 full_name_or_id: Union[str, int],
+                 url_to_repo: str,
                  branch: str = 'master'):
         """
         Initialize a new BaseMiner for a software repository.
 
-        :param path_to_repo: the path to the repository to analyze;
-        :param full_name_or_id: the repository's full name or id (e.g., radon-h2020/radon-repository-miner);
+        :param url_to_repo: the HTTPS url to the remote repository to analyze;
         :param branch: the branch to analyze. Default 'master';
         """
-
-        if host == 'github':
-            self.__host = GithubHost(access_token, full_name_or_id)
-        elif host == 'gitlab':
-            self.__host = GitlabHost(access_token, full_name_or_id)
-        else:
-            raise ValueError("Parameter host must be one among ('github', 'gitlab')")
-
-        self.path_to_repo = path_to_repo
+        match = full_name_pattern.search(url_to_repo)
+        self.full_name = match.groups()[1]
         self.branch = branch
 
         self.exclude_commits = set()  # This is to set up commits known to be non-fixing in advance
@@ -52,10 +44,13 @@ class BaseMiner:
 
         # Get all the repository commits sorted by commit date
         self.commit_hashes = [c.hash for c in
-                              RepositoryMining(self.path_to_repo,
+                              RepositoryMining(path_to_repo=url_to_repo,
+                                               clone_repo_to=os.getenv('TMP_REPOSITORIES_DIR'),
                                                only_in_branch=self.branch,
                                                order='date-order').traverse_commits()]
 
+        self.path_to_repo = os.path.join(os.getenv('TMP_REPOSITORIES_DIR'), self.full_name.split('/')[1])
+
     def discard_undesired_fixing_commits(self, commits: List[str]):
         """
         Discard unwanted fixing-commits
@@ -63,24 +58,31 @@ class BaseMiner:
         """
         pass
 
-    def get_fixing_commits_from_closed_issues(self, labels: Set[str] = None) -> List[str]:
+    def get_fixing_commits_from_closed_issues(self, host: str, labels: Set[str] = None) -> List[str]:
         """
         Collect fixing-commit hashes by analyzing closed issues related to bugs.
         :param labels: bug-related labels (e.g., bug, bugfix, type: bug)
         :return: the set of fixing-commit hashes
         """
 
+        if host == 'github':
+            host = GithubHost(self.full_name)
+        elif host == 'gitlab':
+            host = GitlabHost(self.full_name)
+        else:
+            raise ValueError("Parameter host must be one among ('github', 'gitlab')")
+
         if not labels:
             labels = BUG_RELATED_LABELS
 
         # Get the repository labels (self.get_labels()) and keep only those matching the input labels, if any
-        labels = labels.intersection(self.__host.get_labels())
+        labels = labels.intersection(host.get_labels())
 
         fixes_from_issues = list()
 
         for label in labels:
-            for issue in self.__host.get_closed_issues(label):
-                commit = self.__host.get_commit_closing_issue(issue)
+            for issue in host.get_closed_issues(label):
+                commit = host.get_commit_closing_issue(issue)
                 if (commit in self.exclude_commits) or (commit in self.fixing_commits):
                     continue
                 elif commit:
@@ -182,7 +184,8 @@ class BaseMiner:
                 if self.ignore_file(modified_file.new_path, modified_file.source_code):
                     continue
 
-                if any(file.filepath == modified_file.new_path and file.fic == commit.hash for file in self.exclude_fixing_files):
+                if any(file.filepath == modified_file.new_path and file.fic == commit.hash for file in
+                       self.exclude_fixing_files):
                     continue
 
                 # Identify bug-inducing commits. Dict[modified_file, Set[commit_hashes]]
@@ -222,7 +225,7 @@ class BaseMiner:
         """
         Start labeling process
         :param files: a list of FixingFile objects
-        :return: yields labeled files
+        :return: yields failure prone files
         """
 
         if not (self.fixing_commits or self.fixing_files):
@@ -268,21 +271,6 @@ class BaseMiner:
                             file.filepath = modified_file.old_path
                         break
 
-    def mine(self, labels: Set[str] = None, regex: str = None) -> Generator[FailureProneFile, None, None]:
-        """
-        Mine the repository.
-
-        :param labels: bug-related issues labels.
-        :param regex: the regular expression used to identify fixing-commits from commits message.
-        :return: yields FailureProneFile objects
-        """
-        self.get_fixing_commits_from_closed_issues(labels)
-        self.get_fixing_commits_from_commit_messages(regex)
-        self.get_fixing_files()
-
-        for labeled_file in self.label():
-            yield labeled_file
-
     def sort_commits(self, commits: List[str]):
         """
         Sort fixing commits in chronological order
